==> gbsite-1.0.0.tar.gz: gbsite/htdocs/member/mempage.php <==
<?

/**************************************************
Program name:		mempage.php  
Author:					Allen McGrath (allen@greatbridge.com)

Description:		initial input screen for the member to
								allow him/her to create a "profile" for
								others to view.  Specifically, it will:

								1.  Enter info in headers 1-4 and
										text into text 1 4.
								2.  choose skills he/she has, and apply
										a ranking to each.
								3.  upload any images they want in regard
										to 1-4.
			
Create Date:		9/25/00 

Modified Date(s):	
								9/28/00 allen@greatbridge.com
								-- added new top level cats (languages, database, op sys)
									to the type table and will break these
									out based on the top level cats 
									replaced the skl_query used on the display
**************************************************/
 
/******************************************
SET THE PAGE AND CALL SITE_INFO
*******************************************/
$web_page = "mempage";
include("site_info.php");
$group_group_id = "myprofile";
$context = "<font face=" . $font_1 . " size=2>
			<p>Here's where you can tell the world about yourself, your interests, skills, etc. Everything you enter here is publicly accessible. You can view your current profile, or make changes and additions below:</p>
			</font>";


/******************************************
  SET DO_DEBUG TO YES IF YOU WANT TO SEE DEBUGGING
	AND ANY OTHER NEEDED VARIABLES
******************************************/
	$do_debug = "no";

	# corresponds to the TYPE_ID in TYPE table
	$skills_id = 2;

if (!$temp_id) {
	$temp_id = md5(time());
}

# I NEED THE SKILLS CAT ID IN THE GET AND POST, SO DO IT HERE

/**************************************************************
MODIFIED THE SK_QUERY 9/28 SEE COMMENT AT TOP OF FILE
***************************************************************/

# these are the technology (skill) top level titles

	$sk1_query = "SELECT CAT_ID, CAT_NAME FROM CATEGORY WHERE TYPE_ID = " . $skills_id .
							 "AND PARENT_ID = 0 ORDER BY PARENT_ID";

	$sk1_result =	@pg_exec($conn,$sk1_query);
	
	$skill_total = pg_numrows($sk1_result);
	
	$r = 0;
	while ($row = @pg_fetch_array($sk1_result,$r++)) {
		$title[$row["cat_id"]] = $row["cat_name"];
	}
	

# these are the chidlren of the top level technologies (skills)
	$sk_query  = "SELECT CAT_ID, CAT_NAME, PARENT_ID FROM CATEGORY WHERE " .
						 	 "TYPE_ID = " . $skills_id .
							 "AND PARENT_ID IN " .
							 		"(SELECT CAT_ID FROM CATEGORY WHERE " .
									"PARENT_ID = 0 AND TYPE_ID = $skills_id)" .
							 " ORDER BY PARENT_ID, CAT_NAME";

	$sk_result  = @pg_exec($conn,$sk_query);
	
		$r = 0;
		while ($row = @pg_fetch_array($sk_result,$r++)) {
			$sk_list[] = array( "cat_id" => $row["cat_id"],
			                       "cat_name" => $row["cat_name"],
														 "parent_id" => $row["parent_id"]);
		}

/************************************************
KICK THE USER OUT IF THEY ARE NOT LOGGED IN
*************************************************/

if (empty($member_id)) {
	$context = "<font face=" . $font_1 . " size=2>This area is for members only. Please log in if you are currently a member of " . $official_name . " or sign up today.</font>";
	$context_error[] = "<font face=" . $font_1 . " size=2><a href=/member/memlogin.php>Click here to login</a></font>";
	$context_error[] = "<font face=" . $font_1 . " size=2><a href=/member/memjoin.php>Click here to join " . $official_name . "</a></font>";
	$web_page = "contextpage";
	include($page_template);
	return;
};

/************************************************
IF THE METHOD IS A POST, THE USER HAS ENTERED
INFO AND WE WILL INSERT ROW INTO MEMBER_PAGE AND
MEMBER_SKILL TABLES.  BEFORE DOING SO, WE MUST:

1.  GET THE COLUMNS IN THE MEMBER_PAGE TABLE. -- DITCHED
2.  BUILD THE INSERT QUERY SO IT ALL LINES UP CORRECTLY.

*************************************************/
if ($REQUEST_METHOD == "POST") {

# handle the image if you need to
	if ($imagepath_1 <> "none") {
		chdir("/usr/local/gbsite/htdocs/");
		$dir 	  = opendir(".");
		if ($imagepath_1_type == "image/jpeg") $ext = ".jpg";
		elseif ($imagepath_1_type == "image/gif") $ext = ".gif";
		elseif ($imagepath_1_type == "image/png") $ext = ".png";
		 
		$imagedir =  "images/members/" . $member_id . "/";
		
		if(!is_dir($imagedir)) 
			mkdir($imagedir,0777);

	  copy($imagepath_1, $imagedir . $member_id . "_prof_1" . $ext);
		$image1 =  "/images/members/" . $member_id . "/" .$member_id . "_prof_1" . $ext;;
	
		
		unlink($imagepath_1);
		
	}		
	
# CHECK TO SEE IF WE ALREADY DID THE INSERT OR IF THE MEMBER ALREADY HAS A PAGE

	$chk_query  = "SELECT TEMP_ID FROM MEMBER_PAGE " .
								"WHERE TEMP_ID = '$temp_id' OR MEMBER_ID = $member_id";
	$chk_result = pg_exec($conn,$chk_query);

	if (pg_numrows($chk_result) == 0) {
		$mp_scenario = "INSERT";
		$mp_query = "INSERT INTO MEMBER_PAGE " .
							 "(MEMBER_ID, HEADING_1, TEXT_1, IMAGEPATH_1, " .
							 "HEADING_2, TEXT_2, IMAGEPATH_2, " .
							 "HEADING_3, TEXT_3, IMAGEPATH_3, " .
							 "HEADING_4, TEXT_4, IMAGEPATH_4, TEMP_ID) " .
							 "VALUES($member_id,'$heading_1','$text_1','$image1', " .
							 "'$heading_2','$text_2','$imagepath_2', " .
							 "'$heading_3','$text_3','$imagepath_3', " . 
							 "'$heading_4','$text_4','$imagepath_4', '$temp_id')";
		}
	else {
		if ($image1) $img_query1 = "IMAGEPATH_1 = '" . $image1 . "',";
		$mp_scenario = "UPDATE";
		$mp_query = "UPDATE MEMBER_PAGE SET " .
								"HEADING_1 = '$heading_1', TEXT_1 = '$text_1', " . $img_query1 .
								"HEADING_2 = '$heading_2', TEXT_2 = '$text_2', IMAGEPATH_2 = '$image2', " .
								"HEADING_3 = '$heading_3', TEXT_3 = '$text_3', IMAGEPATH_3 = '$image3', " .
								"HEADING_4 = '$heading_4', TEXT_4 = '$text_4', IMAGEPATH_4 = '$image4', " .
								"TEMP_ID = '$temp_id' " .
								"WHERE TEMP_ID = '$temp_id' OR MEMBER_ID = $member_id";
	}
		
	$mp_result = pg_exec($conn,$mp_query);
	


/******************************************************
DELETE ALL OF THE SKILLS AND RE-INSERT THEM.  THIS
WAY WE ENSURE WE GET EM ALL
******************************************************/
	$skd_query  = "DELETE FROM MEMBER_SKILL WHERE MEMBER_ID = $member_id";
	$skd_result = pg_exec($conn,$skd_query);
	
	while(list($key,$value) = each($sk_list)) {
		$curskill = "skillid_" . $value["cat_id"];
#		echo  "<li>" . $curskill . " =" . $$curskill;
			if ($$curskill) {
				$this_cat = $value["cat_id"];
				$ski_query = "INSERT INTO MEMBER_SKILL (MEMBER_ID,CAT_ID,RATING) " .
										 "VALUES($member_id, $this_cat ,${$curskill})";
#		echo "<li>" . $ski_query;										 
				$ski_result = pg_exec($conn,$ski_query);
			}
	}

    RedirectTo("/member/memmain.php?success=yes");
    exit;

}

/*******************************************************
THIS IS THE START OF THE INITIAL DISPLAY PAGE
********************************************************/
elseif ($REQUEST_METHOD == "GET") {

# SEE IF THE MEMBER ALREADY HAS A RECORD, IF SO SET VARIABLES
	$chk_query  = "SELECT * FROM MEMBER_PAGE " .
								"WHERE TEMP_ID = '$temp_id' OR MEMBER_ID = $member_id";
	
	$skl_query		= "SELECT CAT_ID, RATING " .
								"FROM MEMBER_SKILL " .
								"WHERE MEMBER_ID = $member_id";							

								
																						
	$chk_result = pg_exec($conn,$chk_query);
	$skl_result = pg_exec($conn,$skl_query);
	
	if (pg_numrows($chk_result)) {
		$mem_info    = pg_fetch_object($chk_result,0);
		$heading_1   = $mem_info->heading_1;
		$text_1      = $mem_info->text_1;
		$imagepath_1 = $mem_info->imagepath_1;
		$heading_2   = $mem_info->heading_2;
		$text_2      = $mem_info->text_2;
		$imagepath_2 = $mem_info->imagepath_2;		
		$heading_3   = $mem_info->heading_3;
		$text_3      = $mem_info->text_3;
		$imagepath_3 = $mem_info->imagepath_3;		
		$heading_4   = $mem_info->heading_4;	
		$text_4      = $mem_info->text_4;
		$imagepath_4 = $mem_info->imagepath_4;		

		$r = 0;
		while ($skl_row = @pg_fetch_array($skl_result,$r++)) {
			$skl_arr[$skl_row["cat_id"]] = $skl_row["rating"];
		}

		$context = "<font face=" . $font_1 . " size=2>
					<p>Update your profile information below. If you want to view your profile page, <a href=/member/memprofile.php?" . $member_id .">click here</a>.</p>
					</font>";
								
		
	}

}


/******************************************
EVERYTHING IS FINISHED SO INCLUDE THE TEMPLATE	
******************************************/

	reset($sk_list);
  include($page_template);
?>

==> gbsite-2.0.0.tar.gz: gbsite/htdocs/member/mempage.php <==
<?

/**************************************************
Program name:		mempage.php  
Author:					Allen McGrath (allen@greatbridge.com)

Description:		initial input screen for the member to
								allow him/her to create a "profile" for
								others to view.  Specifically, it will:

								1.  Enter info in headers 1-4 and
										text into text 1 4.
								2.  choose skills he/she has, and apply
										a ranking to each.
								3.  upload any images they want in regard
										to 1-4.
			
Create Date:		9/25/00 

Modified Date(s):	
								9/28/00 allen@greatbridge.com
								-- added new top level cats (languages, database, op sys)
									to the type table and will break these
									out based on the top level cats 
									replaced the skl_query used on the display
**************************************************/
 
/******************************************
SET THE PAGE AND CALL SITE_INFO
*******************************************/
$web_page = "mempage";
include("site_info.php");
$group_group_id = "myprofile";
$context = "<font face=" . $font_1 . " size=2>
			<p>Here's where you can tell the world about yourself, your interests, skills, etc. Everything you enter here is publicly accessible. You can view your current profile, or make changes and additions below:</p>
			</font>";


/******************************************
  SET DO_DEBUG TO YES IF YOU WANT TO SEE DEBUGGING
	AND ANY OTHER NEEDED VARIABLES
******************************************/
	$do_debug = "no";

	# corresponds to the TYPE_ID in TYPE table
	$skills_id = 2;

if (!$temp_id) {
	$temp_id = md5(time());
}

# I NEED THE SKILLS CAT ID IN THE GET AND POST, SO DO IT HERE

/**************************************************************
MODIFIED THE SK_QUERY 9/28 SEE COMMENT AT TOP OF FILE
***************************************************************/

# these are the technology (skill) top level titles

	$sk1_query = "SELECT CAT_ID, CAT_NAME FROM CATEGORY WHERE TYPE_ID = " . $skills_id .
							 "AND PARENT_ID = 0 ORDER BY PARENT_ID";

	$sk1_result =	@pg_exec($conn,$sk1_query);
	
	$skill_total = pg_numrows($sk1_result);
	
	$r = 0;
	while ($row = @pg_fetch_array($sk1_result,$r++)) {
		$title[$row["cat_id"]] = $row["cat_name"];
	}
	

# these are the chidlren of the top level technologies (skills)
	$sk_query  = "SELECT CAT_ID, CAT_NAME, PARENT_ID FROM CATEGORY WHERE " .
						 	 "TYPE_ID = " . $skills_id .
							 "AND PARENT_ID IN " .
							 		"(SELECT CAT_ID FROM CATEGORY WHERE " .
									"PARENT_ID = 0 AND TYPE_ID = $skills_id)" .
							 " ORDER BY PARENT_ID, CAT_NAME";

	$sk_result  = @pg_exec($conn,$sk_query);
	
		$r = 0;
		while ($row = @pg_fetch_array($sk_result,$r++)) {
			$sk_list[] = array( "cat_id" => $row["cat_id"],
			                       "cat_name" => $row["cat_name"],
														 "parent_id" => $row["parent_id"]);
		}

/************************************************
KICK THE USER OUT IF THEY ARE NOT LOGGED IN
*************************************************/

if (empty($member_id)) {
	$context = "<font face=" . $font_1 . " size=2>This area is for members only. Please log in if you are currently a member of " . $official_name . " or sign up today.</font>";
	$context_error[] = "<font face=" . $font_1 . " size=2><a href=/member/memlogin.php>Click here to login</a></font>";
	$context_error[] = "<font face=" . $font_1 . " size=2><a href=/member/memjoin.php>Click here to join " . $official_name . "</a></font>";
	$web_page = "contextpage";
	include($page_template);
	return;
};

/************************************************
IF THE METHOD IS A POST, THE USER HAS ENTERED
INFO AND WE WILL INSERT ROW INTO MEMBER_PAGE AND
MEMBER_SKILL TABLES.  BEFORE DOING SO, WE MUST:

1.  GET THE COLUMNS IN THE MEMBER_PAGE TABLE. -- DITCHED
2.  BUILD THE INSERT QUERY SO IT ALL LINES UP CORRECTLY.

*************************************************/
if ($REQUEST_METHOD == "POST") {

# handle the image if you need to
	if ($imagepath_1 <> "none" && !empty($imagepath_1)) {
		chdir("/usr/local/gbsite/htdocs/");
		$dir 	  = opendir(".");
		if ($imagepath_1_type == "image/jpeg") $ext = ".jpg";
		elseif ($imagepath_1_type == "image/gif") $ext = ".gif";
		elseif ($imagepath_1_type == "image/png") $ext = ".png";
		 
		$imagedir =  "images/members/" . $member_id . "/";
		
		if(!is_dir($imagedir)) 
			mkdir($imagedir,0777);

	  copy($imagepath_1, $imagedir . $member_id . "_prof_1" . $ext);
		$image1 =  "/images/members/" . $member_id . "/" .$member_id . "_prof_1" . $ext;;
	
		
		unlink($imagepath_1);
		
	}		
	
# CHECK TO SEE IF WE ALREADY DID THE INSERT OR IF THE MEMBER ALREADY HAS A PAGE

	$chk_query  = "SELECT TEMP_ID FROM MEMBER_PAGE " .
								"WHERE TEMP_ID = '$temp_id' OR MEMBER_ID = $member_id";
	$chk_result = pg_exec($conn,$chk_query);

	if (pg_numrows($chk_result) == 0) {
		$mp_scenario = "INSERT";
		$mp_query = "INSERT INTO MEMBER_PAGE " .
							 "(MEMBER_ID, HEADING_1, TEXT_1, IMAGEPATH_1, " .
							 "HEADING_2, TEXT_2, IMAGEPATH_2, " .
							 "HEADING_3, TEXT_3, IMAGEPATH_3, " .
							 "HEADING_4, TEXT_4, IMAGEPATH_4, TEMP_ID) " .
							 "VALUES($member_id,'$heading_1','$text_1','$image1', " .
							 "'$heading_2','$text_2','$imagepath_2', " .
							 "'$heading_3','$text_3','$imagepath_3', " . 
							 "'$heading_4','$text_4','$imagepath_4', '$temp_id')";
		}
	else {
		if ($image1) $img_query1 = "IMAGEPATH_1 = '" . $image1 . "',";
		$mp_scenario = "UPDATE";
		$mp_query = "UPDATE MEMBER_PAGE SET " .
								"HEADING_1 = '$heading_1', TEXT_1 = '$text_1', " . $img_query1 .
								"HEADING_2 = '$heading_2', TEXT_2 = '$text_2', IMAGEPATH_2 = '$image2', " .
								"HEADING_3 = '$heading_3', TEXT_3 = '$text_3', IMAGEPATH_3 = '$image3', " .
								"HEADING_4 = '$heading_4', TEXT_4 = '$text_4', IMAGEPATH_4 = '$image4', " .
								"TEMP_ID = '$temp_id' " .
								"WHERE TEMP_ID = '$temp_id' OR MEMBER_ID = $member_id";
	}
		
	$mp_result = pg_exec($conn,$mp_query);
	


/******************************************************
DELETE ALL OF THE SKILLS AND RE-INSERT THEM.  THIS
WAY WE ENSURE WE GET EM ALL
******************************************************/
	$skd_query  = "DELETE FROM MEMBER_SKILL WHERE MEMBER_ID = $member_id";
	$skd_result = pg_exec($conn,$skd_query);
	
	while(list($key,$value) = each($sk_list)) {
		$curskill = "skillid_" . $value["cat_id"];
#		echo  "<li>" . $curskill . " =" . $$curskill;
			if ($$curskill) {
				$this_cat = $value["cat_id"];
				$ski_query = "INSERT INTO MEMBER_SKILL (MEMBER_ID,CAT_ID,RATING) " .
										 "VALUES($member_id, $this_cat ,${$curskill})";
#		echo "<li>" . $ski_query;										 
				$ski_result = pg_exec($conn,$ski_query);
			}
	}

    RedirectTo("/member/memmain.php?success=yes");
    exit;

}

/*******************************************************
THIS IS THE START OF THE INITIAL DISPLAY PAGE
********************************************************/
elseif ($REQUEST_METHOD == "GET") {

# SEE IF THE MEMBER ALREADY HAS A RECORD, IF SO SET VARIABLES
	$chk_query  = "SELECT * FROM MEMBER_PAGE " .
								"WHERE TEMP_ID = '$temp_id' OR MEMBER_ID = $member_id";
	
	$skl_query		= "SELECT CAT_ID, RATING " .
								"FROM MEMBER_SKILL " .
								"WHERE MEMBER_ID = $member_id";							

								
																						
	$chk_result = pg_exec($conn,$chk_query);
	$skl_result = pg_exec($conn,$skl_query);
	
	if (pg_numrows($chk_result)) {
		$mem_info    = pg_fetch_object($chk_result,0);
		$heading_1   = $mem_info->heading_1;
		$text_1      = $mem_info->text_1;
		$imagepath_1 = $mem_info->imagepath_1;
		$heading_2   = $mem_info->heading_2;
		$text_2      = $mem_info->text_2;
		$imagepath_2 = $mem_info->imagepath_2;		
		$heading_3   = $mem_info->heading_3;
		$text_3      = $mem_info->text_3;
		$imagepath_3 = $mem_info->imagepath_3;		
		$heading_4   = $mem_info->heading_4;	
		$text_4      = $mem_info->text_4;
		$imagepath_4 = $mem_info->imagepath_4;		

		$r = 0;
		while ($skl_row = @pg_fetch_array($skl_result,$r++)) {
			$skl_arr[$skl_row["cat_id"]] = $skl_row["rating"];
		}

		$context = "<font face=" . $font_1 . " size=2>
					<p>Update your profile information below. If you want to view your profile page, <a href=/member/memprofile.php?" . $member_id .">click here</a>.</p>
					</font>";
								
		
	}

}


/******************************************
EVERYTHING IS FINISHED SO INCLUDE THE TEMPLATE	
******************************************/

	reset($sk_list);
  include($page_template);
?>
